AccountDBUtils class

账户数据库操作工具类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() Future<void>
清空所有账户
deleteAccount(String username) Future<bool>
删除保存的账户
getAccount(String username) JunnyAccount?
获取指定用户名的账户
getAccounts() List<JunnyAccount>
获取保存的账户
putAccount(String username, String? password) Future<void>
设置保存的账户