BasePersistentStorageMigrator constructor

BasePersistentStorageMigrator()

Create BasePersistentStorageMigrator object to migrate between persistent storage solutions

BasePersistentStorageMigrator only migrates from:

  • local_store (the default implementation of the database in background_downloader).

To add other migrations, extend this class and inject it in the PersistentStorage class that you want to migrate to.

See package background_downloader_sql for an implementation that migrates to a SQLite based PersistentStorage, including migration from Flutter Downloader

Implementation

BasePersistentStorageMigrator();