CameraPickerViewerState class
- Inheritance
-
- Object
- State<
CameraPickerViewer> - CameraPickerViewerState
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- hasErrorWhenInitializing ↔ bool
-
Whether there's any error when initialize the video controller.
初始化视频控制器时是否发生错误
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLoaded ↔ bool
-
Whether the controller has initialized.
控制器是否已初始化
getter/setter pair
- isControllerPlaying → bool
-
Whether the controller is playing.
播放控制器是否在播放
no setter
-
isPlaying
→ ValueNotifier<
bool> -
Whether the player is playing.
播放器是否在播放
final
- isSavingEntity ↔ bool
-
Whether the saving process is ongoing.
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- onError → CameraErrorHandler?
-
no setter
- pickerConfig → CameraPickerConfig
-
no setter
- previewFile → File
-
Construct an File instance through
previewXFile. 通过previewXFile构建 File 实例。latefinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeData
-
latefinal
- videoController → VideoPlayerController
-
Controller for the video player.
视频播放的控制器
latefinal
- widget → CameraPickerViewer
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
buildBackButton(
BuildContext context) → Widget - The back button for the preview section. 预览区的返回按钮
-
buildConfirmButton(
BuildContext context) → Widget - The confirm button for the preview section. 预览区的确认按钮
-
buildForeground(
BuildContext context) → Widget - Actions section for the viewer. Including 'back' and 'confirm' button. 预览的操作区。包括"返回"和"确定"按钮。
-
buildLoading(
BuildContext context) → Widget -
buildPlayControlButton(
BuildContext context) → Widget - A play control button the video playing process. 控制视频播放的按钮
-
buildPreview(
BuildContext context) → Widget -
createAssetEntityAndPop(
) → Future< void> -
When users confirm to use the taken file, create the AssetEntity.
While the entity might returned null, there's no side effects if popping
nullbecause the parent picker will ignore it. -
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
deletePreviewFileIfConfigured(
) → void - If CameraPickerConfig.shouldDeletePreviewFile is true, the preview file will be deleted after unused.
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant CameraPickerViewer oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initializeVideoPlayerController(
) → Future< void> -
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
playButtonCallback(
) → Future< void> - Callback for the play button. 播放按钮的回调
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
videoControllerListener(
) → void - Listener for the video player. 播放器的监听方法
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited