DatabasePerformanceMonitor class

数据库性能监控器

监控数据库操作的性能指标,帮助识别性能瓶颈

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

endDatabaseInitMonitoring() → void
结束数据库初始化监控
generatePerformanceReport() String
生成性能报告
getAllStats() Map<String, dynamic>
获取所有性能统计
getOperationStats(String operationType) Map<String, dynamic>
获取操作统计信息
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordOperation({required String operationType, required Duration duration, bool isError = false}) → void
记录数据库操作性能
startAppMonitoring() → void
开始监控应用启动
startDatabaseInitMonitoring() → void
开始监控数据库初始化
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DatabasePerformanceMonitor
no setter