DateTimeNotifier class

DateProvider is a ChangeNotifier that manages two DateTime objects: _selectedDate and _focusedDate. These dates can be null initially.

Mixed-in types

Constructors

DateTimeNotifier({DateTime? selectedDate, DateTime? focusedDate})
Constructs the DateProvider with initial values for selectedDate and focusedDate as null.

Properties

focusedDate DateTime?
Gets the currently focused date, which can be null.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDate DateTime?
Gets the currently selected date, which can be null.
no setter
selectedState DateTimeSelectedState
Gets the current state of the date and time picker.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setSelectedDate({DateTime? date, DateTimeSelectedState state = DateTimeSelectedState.none}) → void
Sets the selected date and notifies listeners about the change.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited