DateTimeRangePicker class

日期区间选择器组件 支持选择开始时间和结束时间,并处理各种初始状态

Inheritance
Available extensions

Constructors

DateTimeRangePicker({Key? key, DateTime? startTime, DateTime? endTime, DateTime? firstDate, DateTime? lastDate, TimePickerMode pickerMode = TimePickerMode.yMdHms, String? languageCode, Widget startTitleBuilder(BuildContext context, DateTime? startTime)?, Widget endTitleBuilder(BuildContext context, DateTime? startTime)?, dynamic onConfirm(DateTime? startTime, DateTime? endTime)?, DayPeriodConfig? dayPeriodConfig})
const

Properties

dayPeriodConfig DayPeriodConfig?
日期时间段配置
final
endTime DateTime?
初始结束时间
final
endTitleBuilder Widget Function(BuildContext context, DateTime? startTime)?
可选的结束标题构建器
final
firstDate DateTime?
可选的最早日期
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
languageCode String?
当前语言代码
final
lastDate DateTime?
可选的最晚日期
final
onConfirm → dynamic Function(DateTime? startTime, DateTime? endTime)?
确认选择回调
final
pickerMode TimePickerMode
时间选择模式
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime?
初始开始时间
final
startTitleBuilder Widget Function(BuildContext context, DateTime? startTime)?
可选的开始标题构建器
final

Methods

buildPageRoute<T>({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) PageRoute<T>

Available on Widget, provided by the JunnyWidgetExtension extension

构建PageRoute
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DateTimeRangePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited