FlowItemCard class

带流程的业务列表条目卡片

Inheritance
Available extensions

Constructors

FlowItemCard({Key? key, required List<Map<String, dynamic>>? actions, int? taskId, String? title, String? subtitleLabel, dynamic subtitle, String? flowStatus, List<StatusData<String?>>? statusDict, Map<String, dynamic>? info, bool isActionEnabled = false, ValueGetter<bool>? flowEditableGetter, VoidCallback? onInfo, VoidCallback? onEdit, VoidCallback? onDelete, VoidCallback? onStartProcess, List<Widget>? extraActions})

Properties

actions List<Map<String, dynamic>>?
接口的操作按钮数据 用于控制权限
final
extraActions List<Widget>?
其他的操作按钮
final
flowEditableGetter ValueGetter<bool>
是否流程可以编辑
final
flowStatus String?
状态字段值
final
hashCode int
The hash code for this object.
no setterinherited
info Map<String, dynamic>
内容信息
final
isActionEnabled bool
是否可以编辑
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDelete VoidCallback?
删除
final
onEdit VoidCallback?
编辑
final
onInfo VoidCallback?
查看
final
onStartProcess VoidCallback?
启动流程
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusDict List<StatusData<String?>>?
状态字典
final
subtitle → dynamic
子标题(一般为单号)
final
subtitleLabel String?
子标题(一般为单号)
final
taskId int?
任务ID,用于查看流程
final
title String?
标题
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildPageRoute<T>({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) PageRoute<T>

Available on Widget, provided by the JunnyWidgetExtension extension

构建PageRoute
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited