ISpectThemeMode enum

Which brightness ISpect renders its own UI in.

Defaults to dark. system follows the host app's brightness. Ignored when ISpectTheme.useHostColors is true (host brightness wins).

Inheritance
Available extensions

Values

dark → const ISpectThemeMode
light → const ISpectThemeMode
system → const ISpectThemeMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ISpectThemeMode>
A constant List of the values in this enum, in order of their declaration.