JsonScreen class

Inheritance
Available extensions

Constructors

JsonScreen({required Map<String, dynamic> data, Map<String, dynamic>? truncatedData, VoidCallback? onClose, Map<String, dynamic>? correlatedLogData, String? correlatedLogLabel, Duration? correlationDuration, Key? key})
const

Properties

correlatedLogData Map<String, dynamic>?
Optional correlated log data for cross-navigation (e.g. request ↔ response).
final
correlatedLogLabel String?
Label for the navigation chip (e.g. "Request" or "Response").
final
correlationDuration Duration?
Duration between request and response/error.
final
data Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClose VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
truncatedData Map<String, dynamic>?
final

Methods

buildPageRoute<T>({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) PageRoute<T>

Available on Widget, provided by the JunnyWidgetExtension extension

构建PageRoute
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<JsonScreen>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(BuildContext context) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited