JunnyAccount class

用户登录保存的账户信息

Annotations

Constructors

JunnyAccount({int localDbId = 0, String username = '', String? password})
JunnyAccount.fromJson(Map<String, dynamic> json)
从JSON创建实体(支持混合ID策略)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
localDbId int
getter/setter pair
password String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override