JunnyDict_ class
JunnyDict entity fields to define ObjectBox queries.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
enumUniqueId
→ QueryStringProperty<
JunnyDict> -
See JunnyDict.enumUniqueId.
final
-
localDbId
→ QueryIntegerProperty<
JunnyDict> -
See JunnyDict.localDbId.
final
-
timeStamp
→ QueryIntegerProperty<
JunnyDict> -
See JunnyDict.timeStamp.
final