JunnyISpectUtils class abstract final

Junny ISpect 面板控制工具。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isPanelEnabled(BuildContext context) bool
查询当前 ISpect 面板是否显示;无 Scope 时返回 false
togglePanel(BuildContext context) bool
切换当前 ISpect 面板显隐。