JunnyKitConfig class

所有的配置信息

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

api JunnyApiConfig
网络相关配置
latefinal
filePreview JunnyFilePreviewConfig
文件预览相关配置。
latefinal
formControl FormControlStrategy
表单控制策略
latefinal
inspector JunnyInspectorConfig
检查器相关配置
latefinal
loading JunnyLoadingConfig
加载的一些配置
latefinal
other JunnyOtherConfig
其他的一些配置
latefinal
packageFullName String
包名:com.example.app
latefinal
packageName String
包名:app
latefinal
repository JunnyBaseRepositoryConfig
仓储配置(统一入口)
latefinal
route JunnyRouteConfig
一些路由相关配置
latefinal
storage JunnyStorageConfig
存储相关配置
latefinal
theme JunnyThemeConfig
主题颜色配置
latefinal
watermark JunnyWatermarkConfig
水印相关配置
latefinal

Static Methods

buildDefaultOrganizationPage(Map<String, dynamic> data) Widget?
构建默认组织树页面。
init({required String package, JunnyApiConfig? apiConfig, JunnyInspectorConfig? inspectorConfig, JunnyLoadingConfig? loadingConfig, JunnyOtherConfig? otherConfig, JunnyTranslationConfig? translationConfig, JunnyBaseRepositoryConfig? repositoryConfig, JunnyRouteConfig? routeConfig, JunnyStorageConfig? storageConfig, JunnyFilePreviewConfig? filePreviewConfig, JunnyThemeConfig? themeConfig, JunnyWatermarkConfig? watermarkConfig, FormControlStrategy? formControlStrategy}) Future<void>
请注意初始化,必须在runApp方法启动前调用