JunnyLoadingConfig class

The configuration of the loading dialog.

Constructors

JunnyLoadingConfig({AlignmentGeometry alignment = Alignment.center, double backgroundRadius = 8.0, double backgroundSize = 45.0, Color backgroundColorBuilder(BuildContext context)?, BoxDecoration decorationBuilder(BuildContext context)?, bool dismissible = false, Duration duration = const Duration(seconds: 15), Widget indicatorBuilder(BuildContext context)?, Color indicatorColorBuilder(BuildContext context)?, double indicatorSize = 30.0})
const

Properties

alignment AlignmentGeometry
The alignment of the dialog.
final
backgroundColorBuilder Color Function(BuildContext context)?
The background color of the dialog.
final
backgroundRadius double
The radius of the dialog.
final
backgroundSize double
The size of the background.
final
decorationBuilder BoxDecoration Function(BuildContext context)?
The builder of the dialog decoration.
final
dismissible bool
Whether the dialog can be dismissed by user.
final
duration Duration
The duration of the dialog.
final
hashCode int
The hash code for this object.
no setterinherited
indicatorBuilder Widget Function(BuildContext context)?
The builder of the progress indicator.
final
indicatorColorBuilder Color Function(BuildContext context)?
The color of the progress indicator.
final
indicatorSize double
The size of the progress indicator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited