JunnyMenuTreeSnapshot class

子系统菜单树快照。

Constructors

JunnyMenuTreeSnapshot({required List<JunnyMenuSectionViewModel> rootSections, required String subSystemName, required String subSystemCode, String? selectedTabCode})
创建菜单树快照。
const

Properties

activeTabCode String
当前激活的 Tab 编码。
no setter
currentSections List<JunnyMenuSectionViewModel>
当前激活 Tab 的区块列表。
no setter
hashCode int
The hash code for this object.
no setterinherited
rootSections List<JunnyMenuSectionViewModel>
根级区块列表。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionsByTabCode Map<String, List<JunnyMenuSectionViewModel>>
按 Tab 编码组织的区块列表。
no setter
selectedTabCode String?
当前选中的 Tab 编码。
final
subSystemCode String
子系统编码。
final
subSystemName String
子系统名称。
final
tabs List<JunnyWorkbenchTabViewModel>
子系统页顶部 Tab 列表。
no setter

Methods

copyWith({List<JunnyMenuSectionViewModel>? rootSections, String? subSystemName, String? subSystemCode, String? selectedTabCode}) JunnyMenuTreeSnapshot
复制快照并替换局部字段。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited