JunnyNetworkRequestEvents class

网络请求事件

Constructors

JunnyNetworkRequestEvents()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

requestCancel → const String
requestError → const String
requestStart → const String
requestSuccess → const String
requestTimeout → const String