JunnyOSSConfig class

阿里云OSS配置

Constructors

JunnyOSSConfig({required String accessKeyId, required String accessKeySecret, required String bucket, String endpoint = 'oss-cn-hangzhou.aliyuncs.com', Duration expiration = const Duration(hours: 3), String region = 'cn-hangzhou', String? securityToken})
const

Properties

accessKeyId String
访问密钥ID
final
accessKeySecret String
访问密钥Secret
final
bucket String
OSS存储桶名称
final
endpoint String
OSS终端节点
final
expiration Duration
签名过期时间
final
hashCode int
The hash code for this object.
no setterinherited
region String
OSS服务的地域
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityToken String?
安全令牌(可选)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited