JunnyQuickMenu_ class
JunnyQuickMenu entity fields to define ObjectBox queries.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
id
→ QueryIntegerProperty<
JunnyQuickMenu> -
See JunnyQuickMenu.id.
final
-
initials
→ QueryStringProperty<
JunnyQuickMenu> -
See JunnyQuickMenu.initials.
final
-
See JunnyQuickMenu.menuPath.
final
-
pinyin
→ QueryStringProperty<
JunnyQuickMenu> -
See JunnyQuickMenu.pinyin.
final
-
rawJsonBytes
→ QueryByteVectorProperty<
JunnyQuickMenu> -
See JunnyQuickMenu.rawJsonBytes.
final
-
subSystemCode
→ QueryStringProperty<
JunnyQuickMenu> -
See JunnyQuickMenu.subSystemCode.
final
-
title
→ QueryStringProperty<
JunnyQuickMenu> -
See JunnyQuickMenu.title.
final