JunnySingleSystemWorkbenchPage class

Menu 单系统工作台页面。

说明:

  • 单系统工作台不等于只有首层入口卡片;
  • 像 JMC、ECC 这类宿主都可能在工作台内承载多级目录菜单;
  • 因此该页面内置目录继续下钻能力,避免把多级导航逻辑散落到各宿主实现里。
Inheritance
Available extensions

Constructors

JunnySingleSystemWorkbenchPage({Key? key, required JunnySingleSystemWorkbenchController controller, required String subSystemCode, JunnyMenuSearchController? searchController, String? title, JunnySingleSystemWorkbenchAppBarBuilder? appBarBuilder, JunnySingleSystemWorkbenchTopSliversBuilder? topSliversBuilder, FutureOr<void> onMenuTap(JunnyMenuItemViewModel item)?, FutureOr<void> onQuickMenuTap(JunnyMenuItemViewModel item)?, List<JunnyMenuSectionViewModel>? sectionsOverride, String? titleOverride, JunnyMenuGridConfig? gridConfig})
创建单系统工作台页面。
const

Properties

appBarBuilder JunnySingleSystemWorkbenchAppBarBuilder?
自定义 AppBar 构建器。
final
controller JunnySingleSystemWorkbenchController
单系统工作台控制器。
final
gridConfig JunnyMenuGridConfig?
网格布局配置。
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onMenuTap FutureOr<void> Function(JunnyMenuItemViewModel item)?
普通菜单点击回调。
final
onQuickMenuTap FutureOr<void> Function(JunnyMenuItemViewModel item)?
快捷菜单点击回调。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchController JunnyMenuSearchController?
搜索控制器。
final
sectionsOverride List<JunnyMenuSectionViewModel>?
覆盖区块列表,用于单系统工作台内的目录节点继续下钻。
final
subSystemCode String
当前系统编码。
final
title String?
页面标题。
final
titleOverride String?
覆盖标题,用于单系统工作台内的目录节点继续下钻。
final
topSliversBuilder JunnySingleSystemWorkbenchTopSliversBuilder?
顶部附加 sliver 构建器。
final

Methods

buildPageRoute<T>({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) PageRoute<T>

Available on Widget, provided by the JunnyWidgetExtension extension

构建PageRoute
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<JunnySingleSystemWorkbenchPage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited