JunnySubsystemBootstrapCoordinator class

子系统 bootstrap 协调器。

协调器统一承接指定子系统的远端菜单拉取、本地落库与控制器启动。

Inheritance

Constructors

JunnySubsystemBootstrapCoordinator({required JunnyMenuRepository repository, required JunnySubsystemController controller, required String subSystemCode, required JunnySubsystemMenusFetcher fetchMenus})
创建子系统 bootstrap 协调器。

Properties

controller JunnySubsystemController
子系统控制器。
final
fetchMenus JunnySubsystemMenusFetcher
子系统远端菜单拉取器。
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
repository JunnyMenuRepository
菜单仓储。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state JunnyMenuBootstrapState
对外暴露的 bootstrap 状态快照。
no setterinherited
subSystemCode String
目标子系统编码。
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
bootstrap() Future<void>
启动一次 bootstrap。
override
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
updateState(JunnyMenuBootstrapState nextState) → void
更新当前 bootstrap 状态并通知监听者刷新。
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited