JunnyWorkbenchState class

工作台状态。

Constructors

JunnyWorkbenchState({required JunnyLoadStatus status, JunnyWorkbenchSnapshot? snapshot, String? activeSubsystemCode, String? errorMessage})
创建工作台状态。
const

Properties

activeSubsystemCode String?
当前激活的子系统编码。
final
errorMessage String?
错误信息。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot JunnyWorkbenchSnapshot?
工作台快照。
final
status JunnyLoadStatus
加载状态。
final

Methods

copyWith({JunnyLoadStatus? status, Object? snapshot = _workbenchStateSentinel, Object? activeSubsystemCode = _workbenchStateSentinel, Object? errorMessage = _workbenchStateSentinel}) JunnyWorkbenchState
复制状态。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited