TimePicker class

Inheritance
Available extensions

Constructors

TimePicker({Key? key, DateTime? initialTime, ValueSetter<DateTime>? onChanged, PickerMode pickerMode = PickerMode.Hms, DateTime? minTime, DateTime? maxTime, DayPeriodConfig? dayPeriodConfig})
const

Properties

dayPeriodConfig DayPeriodConfig?
日期时间段配置
final
hashCode int
The hash code for this object.
no setterinherited
initialTime DateTime?
初始时间
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxTime DateTime?
最晚时间限制
final
minTime DateTime?
最早时间限制
final
onChanged ValueSetter<DateTime>?
时间变化监听
final
pickerMode PickerMode
选择模式
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildPageRoute<T>({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) PageRoute<T>

Available on Widget, provided by the JunnyWidgetExtension extension

构建PageRoute
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TimePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited