UserInfoDBUtils class

用户信息数据库操作工具类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() Future<void>
清空所有用户信息
deleteUserInfo(String key) Future<bool>
删除指定key的用户信息
getAllUserInfo() Map<String, dynamic>
获取所有用户信息
getTenantId() int?
获取租户ID
getToken() String?
获取token
getUserId() int?
获取用户ID
setTenantId(dynamic value) Future<void>
设置租户ID
setToken(String value) Future<void>
设置token
setUserId(dynamic value) Future<void>
设置用户ID
setUserInfoByKey(String key, dynamic value) Future<void>
设置用户信息
userInfoStream(String key) Stream
根据key获取user info的stream,用来更新用户信息ui