YearPicker class

年份选择器组件

一个可滚动的年份选择器,具有以下特性:

  • 支持设置默认年份 initialDate
  • 可配置年份范围限制 minTimemaxTime
  • 年份变化回调 onChanged
  • 自动处理边界情况和非法输入
  • 支持国际化显示

使用示例:

YearPicker(
  initialDate: DateTime.now(),
  minTime: DateTime(2000),
  maxTime: DateTime(2030),
  onYearChange: (date) => print('选择的年份: ${date.year}'),
)
Inheritance
Available extensions

Constructors

YearPicker({Key? key, DateTime? initialDate, DateTime? minTime, DateTime? maxTime, ValueSetter<DateTime>? onChanged})

Properties

hashCode int
The hash code for this object.
no setterinherited
initialDate DateTime?
初始选择的日期
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxTime DateTime?
可选择的最晚年份
final
minTime DateTime?
可选择的最早年份
final
onChanged ValueSetter<DateTime>?
年份选择变化的回调函数
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildPageRoute<T>({RouteSettings? settings, bool maintainState = true, bool fullscreenDialog = false, bool opaque = true}) PageRoute<T>

Available on Widget, provided by the JunnyWidgetExtension extension

构建PageRoute
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<YearPicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited