BasePersistentStorageMigrator class
Migrates from LocalStorePersistentStorage to another PersistentStorage
- Implemented types
Constructors
- BasePersistentStorageMigrator()
- Create BasePersistentStorageMigrator object to migrate between persistent storage solutions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- log → Logger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
migrate(
List< String> migrationOptions, PersistentStorage toStorage) → Future<String?> -
Migrate data from one of the
migrationOptionsto thetoStorageoverride -
migrateFrom(
String persistentStorageName, PersistentStorage toStorage) → Future< bool> -
Attempt to migrate data from
persistentStorageNametotoStorage -
migrateFromLocalStore(
PersistentStorage toStorage) → Future< bool> - Attempt to migrate from LocalStorePersistentStorage
-
migrateFromPersistentStorage(
PersistentStorage fromStorage, PersistentStorage toStorage) → Future< bool> - Migrate from a persistent storage to our database
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited