ISpectDateTimeFormatter class final
A utility class for formatting DateTime objects into readable strings.
Provides various time formatting styles, including full timestamps and time with milliseconds.
Constructors
- ISpectDateTimeFormatter(DateTime? date)
-
Creates an instance of ISpectDateTimeFormatter with the given
date.const
Properties
- date → DateTime?
-
The
DateTimeinstance to be formatted.final - defaultFormat → String
-
Returns the default compact time representation.
no setter
- fullTime → String
-
Returns the full formatted date and time.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iso8601Local → String
-
Returns an ISO-8601 timestamp with the local timezone offset.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeAndSeconds → String
-
Returns the formatted time with hours, minutes, seconds, and milliseconds.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
relativeFormat(
{required String justNow, required String secondsAgo(int count), required String minutesAgo(int count), required String hoursAgo(int count), DateTime? now}) → String - Returns a localized human-readable relative time string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited