ISpectErrorHandler class
A utility class for handling errors and exceptions in ISpectLogger.
Constructors
- ISpectErrorHandler(ISpectLoggerOptions settings)
-
Creates an instance of
ISpectErrorHandlerwith the given settings.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → ISpectLoggerOptions
-
Configuration settings for ISpectLogger.
final
Methods
-
handle(
Object exception, [StackTrace? stackTrace, String? msg]) → ISpectLogData -
Handles various types of exceptions and errors, converting them into
ISpectLogDataobjects for consistent error reporting. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited