ISpectObserver class abstract
Observer for monitoring ISpectLogger events.
Subclass and override only the methods you need.
Constructors
- ISpectObserver()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
ISpectLogData data) → void - Called when an error-level log is reported.
-
onException(
ISpectLogData data) → void - Called when an exception-level log is reported.
-
onLog(
ISpectLogData data) → void - Called when a general log entry is recorded.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited