InitStatusDBUtils class
初始化状态数据库操作工具类
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- lastLocaleCode → String
-
获取上次选择的语言类型
no setter
Static Methods
-
clear(
) → Future< void> - 清空所有初始化数据
-
deleteInitStatus(
String key) → Future< bool> - 删除初始化数据
-
getAllInitStatus(
) → List< JunnyInitStatus> - 获取所有初始化数据
-
getInitStatus(
String key) → JunnyInitStatus? - 获取初始化数据
-
hasInitStatus(
String key) → bool - 检查初始化状态是否存在
-
isAgreementConfirmed(
) → bool - 获取是否已同意使用app
-
isLocationPrivacyChecked(
) → bool - 获取是否已读定位隐私协议
-
isPrivacyChecked(
) → bool - 获取是否已读隐私协议
-
saveInitStatus(
JunnyInitStatus junnyInitStatus) → Future< void> - 保存初始化数据
-
setAgreementConfirmed(
bool value) → Future< void> - 设置是否已同意使用app
-
setInitStatus(
String key, dynamic value) → Future< void> - 设置初始化数据(通用方法)
-
setLastLocaleCode(
String languageCode) → Future< void> - 设置上次选择的语言类型
-
setLocationPrivacyChecked(
bool value) → Future< void> - 设置是否已读定位隐私协议
-
setPrivacyChecked(
bool value) → Future< void> - 设置是否已读隐私协议