JunnyMenuSearchNavigationController class
搜索结果导航控制器。
Constructors
- 创建搜索结果导航控制器。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
- 为命中的搜索结果生成导航指令。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
JunnyMenuSearchHit hit, {}) → JunnyMenuResolvedNavigation - 为命中的搜索结果生成解析后的导航上下文。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited