JunnyMenuStyleConfig class
Menu 视觉样式配置。
Constructors
- JunnyMenuStyleConfig({JunnyMenuSectionListStyleConfig? sectionListStyle, JunnyMenuSectionCardStyleConfig? sectionCardStyle, JunnyMenuSectionCardStyleConfig? workbenchSectionCardStyle, JunnyMenuSectionCardStyleConfig? subsystemSectionCardStyle, JunnyMenuSectionCardStyleConfig? quickSectionCardStyle, JunnyMenuSectionCardStyleConfig? listSectionCardStyle, JunnyMenuItemStyleConfig? compactGridItemStyle, JunnyMenuItemStyleConfig? regularGridItemStyle, JunnyMenuIconChipStyleConfig? iconChipStyle})
-
创建视觉样式配置。
const
Properties
- compactGridItemStyle → JunnyMenuItemStyleConfig?
-
紧凑 grid 菜单项样式(
crossAxisCount >= 3)。final - hashCode → int
-
The hash code for this object.
no setterinherited
- iconChipStyle → JunnyMenuIconChipStyleConfig?
-
菜单 icon 色块样式。
final
- listSectionCardStyle → JunnyMenuSectionCardStyleConfig?
-
列表型 section 卡片样式。
final
- quickSectionCardStyle → JunnyMenuSectionCardStyleConfig?
-
快捷菜单 section 卡片样式。
final
- regularGridItemStyle → JunnyMenuItemStyleConfig?
-
常规 grid 菜单项样式(
crossAxisCount == 2)。final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionCardStyle → JunnyMenuSectionCardStyleConfig?
-
Section 卡片样式。
final
- sectionListStyle → JunnyMenuSectionListStyleConfig?
-
Section 列表样式。
final
- subsystemSectionCardStyle → JunnyMenuSectionCardStyleConfig?
-
子系统导航 section 卡片样式。
final
- workbenchSectionCardStyle → JunnyMenuSectionCardStyleConfig?
-
工作台入口 section 卡片样式。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited