PackageUtils class
用于管理与包相关的信息,如版本、构建号和应用名称。此类还可以用于检查更新 以及处理版本相关的操作。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appName → String?
-
获取应用的名称。
no setter
- buildNumber → int?
-
获取当前应用的构建号。
no setter
- packageInfo → PackageInfo?
-
获取当前的包信息。
no setter
- packageName → String?
-
获取应用的包名。
no setter
- remoteBuildNumber ↔ int?
-
getter/setter pair
- remoteVersion ↔ String?
-
getter/setter pair
- version → String?
-
获取当前应用的版本号。
no setter
Static Methods
-
initPackageInfo(
) → Future< void> - 初始化包信息(版本、构建号等)。 该方法应该在应用生命周期的早期调用。