WorkflowAttachmentMixin<T extends StatefulWidget> mixin
工作流审批附件通用能力
负责管理审批页中的附件列表、打开附件管理页、序列化提交数据, 以及在审批记录页中按项目配置解析附件。
- Superclass constraints
- State<
T>
- State<
- Available extensions
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWorkflowAttachments → bool
-
是否已选择审批附件
no setter
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → T
-
The current configuration.
no setterinherited
- workflowAttachmentConfig → WorkflowAttachmentConfig
-
审批附件配置
no setter
- workflowAttachmentEnabled → bool
-
当前流程类型下是否启用审批附件
no setter
-
workflowAttachmentFormData
→ Map<
String, dynamic> -
当前表单数据
no setter
-
workflowAttachments
→ List<
Map< String, dynamic> > -
审批附件列表
final
- workflowAttachmentSubSystemCode → String?
-
审批附件所属子系统编码
no setter
-
workflowAttachmentTaskData
→ Map<
String, dynamic> -
当前流程任务数据
no setter
- workflowAttachmentTitle → String
-
审批附件面板标题
no setter
- workflowType → WorkflowType?
-
当前流程类型
no setter
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
appendWorkflowAttachmentPayload(
Map< String, dynamic> payload) → Map<String, dynamic> - 将审批附件写入提交流程 payload
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant T oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
hasWorkflowLogAttachments(
Map< String, dynamic> logItem) → bool - 当前日志条目是否存在审批附件
-
initState(
) → void -
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openWorkflowAttachments(
{required String pageTitle}) → Future< void> - 打开审批附件管理页
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
resolveWorkflowLogAttachments(
Map< String, dynamic> logItem, {CancelToken? cancelToken}) → Future<List< Map< >String, dynamic> > - 解析日志条目的审批附件
-
safeSetState(
FutureOr fn()) → FutureOr< void> -
Available on State<
安全调用 setState。StatefulWidget> , provided by the SafeSetStateExtension extension -
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
whenMounted(
dynamic fn(BuildContext context)) → FutureOr< void> -
Available on State<
安全在组件 mounted 时执行回调。StatefulWidget> , provided by the SafeSetStateExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited